@@ -1,8 +1,7 @@
 #!perl -w
 
 use strict;
-require UNIVERSAL; # for profiling
-require HTTP::Engine;
+use HTTP::Engine;
 
 my $engine = HTTP::Engine->new(
     interface       => {
